# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class AddressType(str, Enum):
    """
    AddressType
    """

    """
    allowed enum values
    """
    MEDICAL_CLAIMS_ADDRESS = 'medical_claims_address'
    PHARMACY_CLAIMS_ADDRESS = 'pharmacy_claims_address'
    VISION_CLAIMS_ADDRESS = 'vision_claims_address'
    DENTAL_CLAIMS_ADDRESS = 'dental_claims_address'
    APPEALS_ADDRESS = 'appeals_address'
    PCP_ADDRESS = 'pcp_address'
    GENERAL_ADDRESS = 'general_address'

    @classmethod
    def from_json(cls, json_str: str) -> AddressType:
        """Create an instance of AddressType from a JSON string"""
        return AddressType(json.loads(json_str))


