# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class CopayDeductibleService(str, Enum):
    """
    CopayDeductibleService
    """

    """
    allowed enum values
    """
    OFFICE_VISIT = 'office_visit'
    SPECIALIST_VISIT = 'specialist_visit'
    EMERGENCY_ROOM = 'emergency_room'
    URGENT_CARE = 'urgent_care'
    PREVENTIVE_CARE = 'preventive_care'
    PRESCRIPTION = 'prescription'
    VISION = 'vision'
    DENTAL = 'dental'
    TELEMEDICINE = 'telemedicine'
    IN_NETWORK_MEDICAL = 'in_network_medical'
    OUT_OF_NETWORK_MEDICAL = 'out_of_network_medical'
    OTHER = 'other'

    @classmethod
    def from_json(cls, json_str: str) -> CopayDeductibleService:
        """Create an instance of CopayDeductibleService from a JSON string"""
        return CopayDeductibleService(json.loads(json_str))


