# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class CopayCategory(str, Enum):
    """
    CopayCategory
    """

    """
    allowed enum values
    """
    COPAY = 'copay'
    COINSURANCE = 'coinsurance'
    DEDUCTIBLE = 'deductible'
    OUT_OF_POCKET_MAX = 'out_of_pocket_max'
    OTHER = 'other'

    @classmethod
    def from_json(cls, json_str: str) -> CopayCategory:
        """Create an instance of CopayCategory from a JSON string"""
        return CopayCategory(json.loads(json_str))


